@@ -31,7 +31,6 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <langinfo.h>
 
 #define GNOME_DESKTOP_USE_UNSTABLE_API
 #include <libgnome-desktop/gnome-languages.h>
@@ -70,7 +69,6 @@ struct _GisTimezonePagePrivate
 
   GnomeWallClock *clock;
   GDesktopClockFormat clock_format;
-  gboolean ampm_available;
   gboolean in_search;
 };
 typedef struct _GisTimezonePagePrivate GisTimezonePagePrivate;
@@ -257,7 +255,7 @@ update_timezone (GisTimezonePage *page, TzLocation *location)
   GDateTime *date;
   gboolean use_ampm;
 
-  if (priv->clock_format == G_DESKTOP_CLOCK_FORMAT_12H && priv->ampm_available)
+  if (priv->clock_format == G_DESKTOP_CLOCK_FORMAT_12H)
     use_ampm = TRUE;
   else
     use_ampm = FALSE;
@@ -309,6 +307,9 @@ map_location_changed (CcTimezoneMap   *map,
 {
   GisTimezonePagePrivate *priv = gis_timezone_page_get_instance_private (page);
 
+  gtk_widget_set_visible (priv->search_overlay, (location == NULL));
+  gis_page_set_complete (GIS_PAGE (page), (location != NULL));
+
   if (!priv->in_search)
     gtk_entry_set_text (GTK_ENTRY (priv->search_entry), "");
 
@@ -367,7 +368,6 @@ gis_timezone_page_constructed (GObject *object)
   GisTimezonePage *page = GIS_TIMEZONE_PAGE (object);
   GisTimezonePagePrivate *priv = gis_timezone_page_get_instance_private (page);
   GError *error;
-  const char *ampm;
   GSettings *settings;
 
   G_OBJECT_CLASS (gis_timezone_page_parent_class)->constructed (object);
@@ -387,12 +387,6 @@ gis_timezone_page_constructed (GObject *object)
   priv->clock = g_object_new (GNOME_TYPE_WALL_CLOCK, NULL);
   g_signal_connect (priv->clock, "notify::clock", G_CALLBACK (on_clock_changed), page);
 
-  ampm = nl_langinfo (AM_STR);
-  if (ampm == NULL || ampm[0] == '\0')
-    priv->ampm_available = FALSE;
-  else
-    priv->ampm_available = TRUE;
-
   settings = g_settings_new (CLOCK_SCHEMA);
   priv->clock_format = g_settings_get_enum (settings, CLOCK_FORMAT_KEY);
   g_object_unref (settings);
@@ -471,11 +465,10 @@ gis_timezone_page_init (GisTimezonePage *page)
   gtk_widget_init_template (GTK_WIDGET (page));
 }
 
-void
+GisPage *
 gis_prepare_timezone_page (GisDriver *driver)
 {
-  gis_driver_add_page (driver,
-                       g_object_new (GIS_TYPE_TIMEZONE_PAGE,
-                                     "driver", driver,
-                                     NULL));
+  return g_object_new (GIS_TYPE_TIMEZONE_PAGE,
+                       "driver", driver,
+                       NULL);
 }
